# Vehicular experiments dataset

### Objective:
Capture multiple parameters of 802.11 links between a stationary AP and a vehicle moving at realistic speeds. We use 3 different types of 802.11 standards: n, ac (wave 1) and ad.

###Experiment description:

* Vehicle movement on a grid with distances [here](https://www.dropbox.com/s/dt32uxr2b53eqh5/vehicle-movement.gif?dl=1). Notice building at SW corner of intersection : blocks line-of-sight to AP when vehicle is on the lower N-S portion of the circuit 

* Data divided in traces, performed on different dates, using different vehicles to support the AP on the roof, as shown below:

| trace nr | date | start time | n(n) | n(ac) | n(ad) | vehicle AP | n(clients) |
|-----|------------|----------|------|------|-----| --- | --- |
| 302 | 2019-08-20 | 10:28:45 | 3262 | 2787 | 423 | honda civic sedan 2001 | 1 |
| 303 | 2019-08-20 | 11:26:23 | 3374 | 3027 | 312 | - | 2 |
| 304 | 2019-08-20 | 12:39:46 | 1711 | 216  | 14  | - | 3 (n & ac) 2 (ad) |
| 401 | 2019-08-22 | 10:19:24 | 1685 | 1681 | 545 | peugeot partner 2002 | 1 |
| 402 | 2019-08-22 | 10:48:26 | 2859 | 2827 | 764 | - | 2 |
| 403 | 2019-08-22 | 11:39:36 | 135 | 135 | 116 | - | 2 |
| 404 | 2019-08-22 | 11:42:50 | 114 | 114 | 53 | - | 2 |
| 405 | 2019-08-22 | 11:45:07 | 2019 | 2019 | 507 | - | 2 |

* **APs:** all positioned at coordinates {lat : 41.111879, lon : -8.631146}

| ap | device | 802.11 type | channel | cntr. freq (MHz) | bw (MHz) |
|----|--------|-------------|---------|------------------|----------|
| unifi-003  | ubiquiti ac lite | n  | 6 | 2437 | 20 |
| unifi-001 | - | ac | 40 | 5200 | 40 |
| tp-01 | tp-link talon ad7200* | ad | 1 | 60480 | 2160 |

*running tp-link's original firmware, not OpenWrt

* **Main clients:** all positioned in the moving vehicle's roof, a vw golf mk3

| 802.11 type | radio | nr. antennas | laptop |
|---|---|---|---|
| n | csl usb 2.0 wlan Adapter 300 Mbps | 2 | m1 |
| ac | tp-link archer t4uh | 2 | w4 |
| ad | tp-link talon ad7200 (tp-03) | - | w4 |

* **Background clients:** the purpose is to increase channel util.

| 802.11 type | radio | nr. antennas | laptop | position |
|---|---|---|---|---|
| n | tp-link wn722n | 1 | w2 | fixed, ~2m away from AP |
| n | tp-link wn722n | 1 | w3 | '' |
| ac | csl usb 2.0 wlan Adapter 300 Mbps | 2 | w2 | '' |
| ac | csl usb 2.0 wlan Adapter 300 Mbps | 2 | w3 | '' |
| ad | tp-link talon ad7200 (tp-04) | - | macbook | stopped vehicle's roof |

* **Monitor nodes:** all positioned in the moving vehicle's roof

| 802.11 type | radio | nr. antennas | laptop |
|---|---|---|---|---|
| n | csl usb 2.0 wlan Adapter 300 Mbps | 2 | m1 |
| ac | tp-link talon ad7200 (tp-02) | 8 | w4 |
| ad | tp-link talon ad7200 (tp-02) | - | w4 |

###Dataset structure:

All the packet captures are already digested and ready to use in the file `wifi-exp-log-summary.csv`. An explanation of the fields below:

* **systime** : system time (1 Hz resolution) that this row refers to. All node clocks were synchronized through NTP.
* **traceNr** : nr. of the trace the row belongs to. 
* **lon** : longitude (in degrees) reported by the receiver's GPS at `systime`
* **lat** : latitude reported by the receiver's GPS at `systime`
* **receiverAlt** : altitude (in meters) reported by the receiver's GPS at `systime`
* **receiverX** : x coordinate of the receiver's position when space is discretized as a Cartesian plane and the sender is set to be the origin of the coordinate system. The x axis corresponds to east-west (positive values are east, negative values are west). Unit is meters.
* **receiverY** : y coordinate of the receiver's position when space is discretized as a Cartesian plane
* **receiverDist** : distance (in meters) of receiver to ap(s)
* **receiverSpeed** : speed (in m/s) reported by the receiver's GPS at `systime`
* **receiverId** : system-specific id for the client (in the vehicle)
* **senderId** : system-specific id for the ap serving the client (side of the road)
* **isIperfOn** : 1 if row's `systime` corresponds to a period where our UDP packet consumer application is known to have been running on the receiver side.
* **isInLap** : 1 if this row's systime has been marked as being part of a time period where clients were doing laps around the APs, 0 otherwise.
* **rssiMean** : the mean of the RSSI (Received Signal Strength Indicator) values of frames received by the client from the ap during the 1-second period systime period the row refers to. 
* **snrMean** : SNR (signal to noise ratio) retrieved from 802.11ad sectore sweep frames.
* **channelFreq** : center frequency of the WiFi channel used, in MHz.
* **channelBw** : bandwidth of the WiFi channel used, in MHz.
* **channelUtil** : percentage of time the wireless medium was sensed to be busy during the 1-second period systime period the row refers to. **In traces 40x, the 802.11n and ac routers didn't log channel busy time, and as such we had to approximate channel util. based on x,y coordinates and nr. of active clients.**
* **wifiType** : 802.11 type (e.g., n, ac or ad).
* **nrClients** : nr. of parallel clients operating in `wifiType` mode, on the same channel and bandwidth as `receiverId`.
* **dataRateMedian** : the median of the bitrate values of frames received by the client from the ap during the 1-second period systime period the row refers to.
* **dataRateMean** : the mean of the bitrate values of frames received by the client from the ap during the 1-second period systime period the row refers to.
* **nBytesReceived** : total number of bytes received by the client from the ap during the 1-second period systime period the row refers to.
* **tghptConsumer** : throughput reported by the UDP packet consumer application, during the 1-second period systime period the row refers to.
* **nRetries**  : nr. of WLAN-level re-transmissions on 1 second period
* **meanBeaconRssi** : mean RSSI measured from beacons in 1 second period. nan values are filled with -100 dBm.
* **meanInterBeaconTime** : mean interval between consecutive beacons, within 1 second period. nan values are filled with 1 sec.
* **nBeacons** : total nr. of beacons received by client within 1 second period.
